CoerceReturn

Trait CoerceReturn 

pub trait CoerceReturn<T>: Sized {
    type CoerceTo;
}
Computes the type that the T argument is converted into by IsPanicFmt::coerce.

This trait is sealed, it’s implemented by IsStdType and IsCustomType, and cannot be implemented by any other type.

Required Associated Types

type CoerceTo

The type that the T argument is converted into.

Dyn Compatibility

This trait is not dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety".

Implementors